<?php

namespace App\Exceptions;

use Illuminate\Foundation\Exceptions\Handler as ExceptionHandler;
use Throwable;

class Handler extends ExceptionHandler
{
    /**
     * The list of the inputs that are never flashed to the session on validation exceptions.
     *
     * @var array<int, string>
     */
    protected $dontFlash = [
        'current_password',
        'password',
        'password_confirmation',
    ];

    /**
     * Register the exception handling callbacks for the application.
     */
    public function register(): void
    {
        $this->reportable(function (Throwable $e) {
            //
        });
        $this->renderable(function (AuthenticationException $e, $request) {
        return $request->expectsJson()
                    ? response()->json(['error' => 'Unauthenticated. Invalid or expired token.'], Response::HTTP_UNAUTHORIZED)
                    : redirect()->guest(route('login'));
    });

    $this->renderable(function (ValidationException $e, $request) {
        return $request->expectsJson()
                    ? response()->json(['error' => $e->getMessage()], Response::HTTP_UNPROCESSABLE_ENTITY)
                    : redirect()->guest(route('login'));
    });
    }
}
