<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Google\Client;

define('FIREBASE_API_KEY', 'YOUR_FIREBASE_API_KEY');

class AlertsController extends Controller
{
    public function allPersonalAlerts(Request $request)
    {
        // Your existing method implementation
    }

    public function createAlert(Request $request)
    {
        // Your existing method implementation
    }

    public function send($registration_ids, $notificationTitle, $notificationBody)
    {
        $accessToken = $this->getAccessToken(); // Retrieve the Bearer token

        foreach ($registration_ids as $registration_id) {
            $fields = [
                'message' => [
                    'token' => $registration_id,
                    'notification' => [
                        'title' => $notificationTitle,
                        'body' => $notificationBody,
                        'image' => 'https://washly.churchapp.co.ke/public/smallest_logo.png',
                    ],
                    'data' => [
                        'title' => $notificationTitle,
                        'body' => $notificationBody,
                        'sound' => 'default',
                        'image' => 'https://washly.churchapp.co.ke/public/smallest_logo.png',
                    ],
                ],
            ];

            $response = $this->sendPushNotification($fields, $accessToken);

            Log::info("Response from send method for token $registration_id: " . $response);
        }

        return response()->json(['success' => true, 'message' => 'Alerts sent successfully.']);
    }

    public function sendPushNotification($fields, $accessToken)
    {
        $url = 'https://fcm.googleapis.com/v1/projects/eastleighxp-9895e/messages:send';

        $headers = [
            'Authorization: Bearer ' . $accessToken,
            'Content-Type: application/json',
        ];

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));

        $result = curl_exec($ch);
        if ($result === false) {
            die('Curl failed: ' . curl_error($ch));
        }

        curl_close($ch);
        return $result;
    }

    public function getAccessToken()
    {
        $client = new Client();
        $client->setAuthConfig(storage_path('app/service-account.json'));
        $client->addScope('https://www.googleapis.com/auth/firebase.messaging');

        $token = $client->fetchAccessTokenWithAssertion();
        return $token['access_token'];
    }

    public function sendAlert(Request $request)
    {
        $pushMessage = $request->message;
        $pushTitle = $request->title;
        $id = $request->userID;

        Log::info("Sending alert to user ID: $id with title: $pushTitle and message: $pushMessage");

        $deviceID = DB::table("users")
            ->where("id", $id)
            ->pluck("deviceid");

        Log::info("Retrieved device ID: " . json_encode($deviceID));

        if ($deviceID->isEmpty()) {
            Log::error("No device ID found for user ID: $id");
            return response()->json(['success' => false, 'message' => 'No device ID found.'], 404);
        }

        $response = $this->send($deviceID, $pushTitle, $pushMessage);

        Log::info("Response from send method: " . $response);

        return response()->json(['success' => true, 'message' => 'Alert sent successfully.']);
    }
}
