<?php
namespace App\Http\Controllers;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use App\Models\Category;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class CategoryController extends Controller
{
    public function index()
    {
        $categories = Category::select(
            'categories.id',
            'categories.cname as cname',
            'categories.cimage as cimage',
            'categories.updated_at as updatedAt',
            'categories.created_at as createdAt',
            DB::raw('COUNT(product_categories.productid) as product_count')
        )
            ->leftJoin('product_categories', 'categories.id', '=', 'product_categories.categoryid')
            ->groupBy('categories.id')
            ->groupBy('categories.cname')
            ->groupBy('categories.cimage')
            ->groupBy('categories.updated_at')
            ->groupBy('categories.created_at')
            ->get();
        
        return response()->json(['categories' => $categories]);
    }
    public function createCategory(Request $request)
{
    $validator = Validator::make($request->all(), [
        'categoryname' => 'required|string|max:255',
        'imageFile' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:5048',
    ]);

    if ($validator->fails()) {
        return response()->json(['message' => 'Validation Error', 'error' => $validator->errors()], 400); // Validation Error
    }

    try {
        $imagePath = null;
        if ($request->hasFile('imageFile')) {
            $file = $request->file('imageFile');
            $filename = Str::random(20) . '.' . $file->getClientOriginalExtension();
            $file->move(public_path('cimages'), $filename);
            $imagePath = 'cimages/' . $filename;
        }

        $category = Category::create([
           'cname' => $request->categoryname,
            'cimage' => $imagePath ? basename($imagePath) : null,
        ]);

        return response()->json(['message' => 'Category created successfully.', 'category' => $category], 200); // Category created successfully. The category will be reviewed before being published.
    } catch (\Exception $e) {
        return response()->json(['message' => 'Error creating category', 'error' => $e->getMessage()], 500); // Error creating category
    }
}

}
