<?php
namespace App\Http\Controllers;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Hash;
use App\Models\User;
use Illuminate\Http\Request;
use Carbon\Carbon;
use Illuminate\Support\Str;

class PasswordResetController extends Controller
{
    public function requestReset(Request $request)
    {
        $request->validate(['email' => 'required|email']);

        if (!$request->has('email')) {
            return response()->json(['message' => 'Email is missing'], 400);
        }

        $user = User::where('email', $request->email)->first();

        if (!$user) {
            return response()->json(['message' => 'User not found'], 404);
        }

        $token =  Str::random(60);
        $expiration = Carbon::now()->addHours(2);
        DB::table('password_reset_tokens')->where('email', $user->email)->delete();
        DB::table('password_reset_tokens')->insert([
            'email' => $user->email,
            'token' => Hash::make($token),
            'expires_at' => $expiration,
            'created_at' => now(),
        ]);
        $resetLink = 'https://churchapp.co.ke/eastleighxpp/public/api/password/reset?token=' . $token;
        
       Mail::send('emails.reset_password', ['user' => $user, 'resetLink' => $resetLink], function ($message) use ($user) {
    $message->to($user->email)->subject('Reset Your Password');
});

        return response()->json(['message' => 'Password reset link has been sent to your email']);
    }

    public function resetPassword(Request $request)
    {
        $request->validate([
            'email' => 'required|email',
            'password' => 'required|min:8',
            'token' => 'required',
        ]);

        $user = User::where('email', $request->email)->first();

        if (!$user) {
            return response()->json(['message' => 'User not found'], 404);
        }

        $tokenData = DB::table('password_reset_tokens')->where('email', $request->email)->first();

        if (!$tokenData || Carbon::now()->gt($tokenData->expires_at)) {
            return response()->json(['message' => 'Invalid or expired token'], 400);
        }

        if (!Hash::check($request->token, $tokenData->token)) {
            return response()->json(['message' => 'Invalid or expired token'], 400);
        }

        $user->password = Hash::make($request->password);
        $user->save();

        DB::table('password_reset_tokens')->where('email', $user->email)->delete();

        return response()->json(['message' => 'Password has been reset successfully']);
    }
}
