<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\DB;
use App\Services\EmailService;

class PaymentCallBack extends Controller
{
    public function getMpesaCallBack(Request $request)
    {
      $data = json_decode($request->getContent());
        
        if (isset($data->Body->stkCallback)) {
            $stkCallback = $data->Body->stkCallback;
            $resultCode = $stkCallback->ResultCode;

            if ($resultCode == 0) {
                $CallbackMetadata = $stkCallback->CallbackMetadata->Item;

                $Amount = null;
                $MpesaReceiptNumber = null;
                $TransactionDate = null;
                $PhoneNumber = null;

                foreach ($CallbackMetadata as $item) {
                    switch ($item->Name) {
                        case "Amount":
                            $Amount = $item->Value;
                            break;
                        case "MpesaReceiptNumber":
                            $MpesaReceiptNumber = $item->Value;
                            break;
                        case "TransactionDate":
                            $TransactionDate = $item->Value;
                            break;
                        case "PhoneNumber":
                            $PhoneNumber = $item->Value;
                            break;
                    }
                }

                $formattedContact = str_replace("254", "0", $PhoneNumber);

                if ($Amount > 0) {
                    $merchantRequestID = $stkCallback->MerchantRequestID;
                    $checkoutRequestID = $stkCallback->CheckoutRequestID;

                    $affectedRows = DB::update(
                        "UPDATE orders SET status = ?, paymentStatus = ?, mpesaCode = ?, payingPhone = ?,paymentTime=? WHERE checkoutID = ?",
                        ['Processing' , 1, $MpesaReceiptNumber, $formattedContact,now(), $checkoutRequestID]
                    );

                    if ($affectedRows > 0) {
                        $user = DB::table("orders")
                            ->where("checkoutID", $checkoutRequestID)
                            ->first();

                        if ($user) {
                            $name = DB::table("users")
                                ->where("id", $user->userId)
                                ->first();

                            if ($name) {
                                DB::table('mpesa')->insert([
                                    'rid' => 0,
                                    'orderID'=>$user->ordernumber,
                                    'firstname' => $name->firstname,
                                    'secondname' => $name->lastname,
                                    'amount' => $Amount,
                                    'MPESAcode' => $MpesaReceiptNumber,
                                    'phone' => $formattedContact,
                                    'checkoutID' => $user->checkoutID,
                                    'created_date' => now(),
                                ]);

                                $message = "Hello, {$name->firstname}. We acknowledge receiving KES {$Amount} from you. Your order is being processed.";
                                $deviceID = DB::table("users")
                                    ->where("id", "=", $user->id)
                                    ->pluck("deviceid");

                                (new AlertsController)->send($deviceID, "Funds Received", $message);
                             }
                        }
                    } else {
                       /// $this->handleNewUserOrMistakenPayment($merchantRequestID, $Amount, $MpesaReceiptNumber, $formattedContact, $emailService);
                    }
                }
            } else {
                Log::error("MPesa transaction failed with ResultCode: $resultCode");
            }
        } else {
            Log::error("Invalid MPesa Callback data");
        }

        echo "Tested";
    }

}
