<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\ProductReview;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\ValidationException;
use Illuminate\Support\Facades\DB;

class ReviewController extends Controller
{
    public function submitReview(Request $request)
    {
        try {
            // Validate the incoming request data
            $validator = Validator::make($request->all(), [
                'userId' => 'required|integer|exists:users,id',
                'productId' => 'required|integer|exists:products,id',
                'rating' => 'required|integer|min:1|max:5',
                'title' => 'nullable|string|max:255',
                'comment' => 'nullable|string',
            ]);

            if ($validator->fails()) {
                return response()->json(['errors' => $validator->errors()], 422);
            }

            $validatedData = $validator->validated();

            // Create a new review
            $review = new ProductReview();
            $review->userid = $validatedData['userId'];
            $review->productid = $validatedData['productId'];
            $review->rating = $validatedData['rating'];
            $review->title = $validatedData['title'] ?? null;
            $review->comment = $validatedData['comment'] ?? null;
            $review->save();

            return response()->json(['message' => 'Review submitted successfully'], 201);
        } catch (ValidationException $e) {
            return response()->json(['errors' => $e->errors()], 422);
        } catch (\Exception $e) {
            return response()->json(['error' => 'An unexpected error occurred. Please try again later.'], 500);
        }
    }
    
    public function getProductReviews($productId)
    {
        // Fetch reviews for the given product ID with user information
        $reviews = DB::table('product_reviews')
            ->join('users', 'product_reviews.userid', '=', 'users.id')
            ->where('product_reviews.productid', $productId)
            ->select(
                'product_reviews.rating',
                'product_reviews.title',
                'product_reviews.comment',
                'product_reviews.created_at',
                DB::raw("CONCAT(users.firstname, ' ', users.lastname) as userName")
            )
            ->get();

        return response()->json($reviews, 200);
    }


}
