<?php

namespace App\Http\Controllers;

use App\Models\Shop;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Str;

class ShopController extends Controller
{
    public function index(Request $request)
    {
        $number = $request->input('number', 0);

        $shopsQuery = DB::table('shops')
            ->join('users', 'shops.sellerid', '=', 'users.id')
            ->select('shops.id as shop_id', 'shops.shopname', 'shops.live', 'shops.shopimage', 'shops.sellerid', 'users.id as user_id', 'users.firstname', 'users.lastname')
            ->where("shops.live", 1);

        $shops = $number == 0 ? $shopsQuery->get() : $shopsQuery->take($number)->get();

        return response()->json(['shops' => $shops], 200);
    }

   public function adminAllShops(Request $request)
{
    $shopsQuery = DB::table('shops')
        ->join('users', 'shops.sellerid', '=', 'users.id')
        ->select('shops.id as shop_id', 'shops.shopname', 'shops.live', 'shops.location', 'shops.shopimage', 'shops.sellerid', 'users.id as user_id', 'users.firstname', 'users.lastname');

    $shops = $shopsQuery->get();

    return response()->json(['shops' => $shops], 200);
}


    public function toggleLive(Request $request, $id)
    {
        $shop = Shop::find($id);

        if (!$shop) {
            return response()->json(['message' => 'Shop not found'], 404);
        }

        $shop->live = !$shop->live;
        $shop->save();

        return response()->json(['message' => 'Live status toggled successfully', 'shop' => $shop], 200);
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'sellerid' => 'required|numeric',
            'shopname' => 'required|string|max:100',
            'shopimage' => 'required|string|max:100',
            'description' => 'required|string|max:200',
            'location' => 'required|string|max:200',
            'shop_call' => 'nullable|string|max:20',
            'live' => 'required|boolean',
        ]);

        if ($validator->fails()) {
            return response()->json(['message' => 'Validation Error', 'errors' => $validator->errors()], 400);
        }

        $shop = new Shop([
            'sellerid' => $request->sellerid,
            'shopname' => $request->shopname,
            'shopimage' => $request->shopimage,
            'description' => $request->description,
            'location' => $request->location,
            'shop_call' => $request->shop_call,
            'live' => $request->live,
        ]);

        $shop->save();

        return response()->json(['message' => 'Shop created successfully', 'shop' => $shop], 201);
    }

    public function becomeSeller(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'userId' => 'required|exists:users,id',
            'shopName' => 'required|string|max:255',
            'phone' => 'required|string|max:15',
            'description' => 'required|string',
            'address' => 'required|string|max:255',
            'logoFile' => 'nullable|image|mimes:jpeg,png,jpg,gif,svg|max:5048',
        ]);

        if ($validator->fails()) {
            return response()->json(['message' => 'Validation Error', 'errors' => $validator->errors()], 400);
        }

        try {
            $logoPath = null;
            if ($request->hasFile('logoFile')) {
                $file = $request->file('logoFile');
                $filename = Str::random(20) . '.' . $file->getClientOriginalExtension();
                $file->move(public_path('shopimages'), $filename);
                $logoPath = 'shopimages/' . $filename;
            }

            $shop = Shop::create([
                'sellerid' => $request->userId,
                'shopname' => $request->shopName,
                'shop_call' => $request->phone,
                'description' => $request->description,
                'location' => $request->address,
                'shopimage' => basename($logoPath),
            ]);

            return response()->json(['message' => 'Shop created successfully', 'shop' => $shop], 200);
        } catch (\Exception $e) {
            return response()->json(['message' => 'Error creating shop', 'error' => $e->getMessage()], 500);
        }
    }
}
