<?php
namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\DB;
use App\Models\User;

class UserController extends Controller
{
    public function register(Request $request)
{
    $emailExists = User::where('email', $request->input('email'))->exists();
    $phoneExists = User::where('phone', $request->input('phone'))->exists();

    if ($emailExists) {
        return response()->json(['error' => 'Email already exists'], 401);
    }

    if ($phoneExists) {
        return response()->json(['error' => 'Phone number already exists'], 401);
    }

    $user = User::create([
        'firstname' => $request->input('firstname'),
        'lastname' => $request->input('lastname'),
        'email' => $request->input('email'),
        'phone' => $request->input('phone'),
        'password' => Hash::make($request->input('password')),
        // Add more fields as needed
    ]);

    return response()->json(['message' => 'User created successfully', 'user' => $user]);
}

    
public function login(Request $request)
{
    $credentials = $request->validate([
        'login' => 'required',
        'password' => 'required',
        'device_id' => 'required',
    ]);

    if (!isset($credentials['login'])) {
        return response()->json(['error' => 'Please provide email or phone'], 400);
    }

    // Determine if login is an email or phone number
    $loginType = filter_var($credentials['login'], FILTER_VALIDATE_EMAIL) ? 'email' : 'phone';

    if (Auth::attempt([$loginType => $credentials['login'], 'password' => $credentials['password']])) {
        $user = Auth::user();
        $user->deviceid = $credentials['device_id']; // Update device_id
        $user->save();

        $hasShop = DB::table('shops')->where('sellerid', $user->id)->exists() ? 1 : 0;
        $user->hasShop = $hasShop;

        $token = $user->createToken('YourAppName')->plainTextToken;
        return response()->json([
            'message' => 'Login successful',
            'token' => $token,
            'user' => $user
        ]);
    }

    return response()->json(['error' => 'Invalid credentials'], 401);
}

public function emailLogin(Request $request)
{
    $data = $request->validate([
        'email' => 'required|email',
        'key' => 'required',
    ]);

    // Check if the user with the given email exists
    $user = User::where('email', $data['email'])->first();

    if (!$user) {
        return response()->json(['error' => 'There is no user associated with that email.'], 404);
    }

    // Update the device ID
    $user->deviceid = $data['key'];
    $user->save();

    // Check if the user has a shop
    $hasShop = DB::table('shops')->where('sellerid', $user->id)->exists() ? 1 : 0;
    $user->hasShop = $hasShop;

    // Generate a token for the user
    $token = $user->createToken('YourAppName')->plainTextToken;

    return response()->json([
        'message' => 'Login successful',
        'token' => $token,
        'user' => $user
    ], 200);
}




    
   public function updateDetails(Request $request, $id)
{
    $user = User::findOrFail($id);

    $data = [];

    if ($request->filled('firstname')) {
        $data['firstname'] = $request->input('firstname');
    }

    if ($request->filled('lastname')) {
        $data['lastname'] = $request->input('lastname');
    }

    if ($request->filled('email')) {
        $data['email'] = $request->input('email');
    }

    if ($request->filled('phone')) {
        $data['phone'] = $request->input('phone');
    }

    if ($request->filled('address')) {
        $data['address'] = $request->input('address');
    }

    if ($request->filled('password')) {
        $password = $request->input('password');
        $data['password'] = Hash::make($password);
    }

    $user->update($data);

    return response()->json(['message' => 'User details updated successfully', 'user' => $user]);
}
public function deleteUser($id)
{
    $user = User::find($id);

    if (!$user) {
        return response()->json(['message' => 'User does not exist']);
    }

    $user->delete();

    return response()->json(['message' => 'User deleted successfully']);
}
}
