<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\UserController;
use App\Http\Controllers\PasswordResetController;
use App\Http\Controllers\ProductController;
use App\Http\Controllers\ShopController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\OrderController;
use App\Http\Controllers\PaymentCallBack;
use App\Http\Controllers\AlertsController;
use App\Http\Controllers\ReviewController;
/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "api" middleware group. Make something great!
|
*/
//users
Route::post('/login', [UserController::class, 'login']);
Route::get('/email-login', [UserController::class, 'emailLogin']);
Route::post('/register',[UserController::class, 'register']);
Route::post('/user/details/{id}', [UserController::class, 'updateDetails']);
Route::post('/password/reset/request', [PasswordResetController::class, 'requestReset']);
Route::get('/password/reset', [PasswordResetController::class, 'resetPassword']);
Route::delete('/user/{id}', [UserController::class, 'deleteUser']);
//products
Route::post('/products', [ProductController::class, 'create']);
Route::get('/admin-products', [ProductController::class, 'indexAdmin']);
Route::get('/seller-products', [ProductController::class, 'indexSellerProducts']);
Route::get('products-extra-images/{id}', [ProductController::class, 'getProductExtraImages']);
Route::get('/products/search', [ProductController::class, 'searchProducts']);
Route::get('/products', [ProductController::class, 'index']);
Route::post('/create-product', [ProductController::class, 'createProduct']);
Route::get('/products/{id}', [ProductController::class, 'show']);
Route::get('/fetch-product/{id}', [ProductController::class, 'fetchProduct']);
Route::post('/product-edit/{id}', [ProductController::class, 'editProduct']);
Route::delete('/products/{id}', [ProductController::class, 'destroy']);
Route::get('/featured-products/', [ProductController::class, 'indexFeatured']);
Route::get('/discounted-products', [ProductController::class, 'indexDiscounted']);
Route::get('/trending-products', [ProductController::class, 'indexTrending']);
Route::get('/products/categories/{categoryID}', [ProductController::class, 'indexProductsByCategories']);
Route::get('/user-favorites/{userid}', [ProductController::class, 'favouriteForUser']);
Route::delete('/delete-product/{id}', [ProductController::class, 'deleteProduct']);
Route::post('/toggle-favorite/{id}', [ProductController::class, 'toggleFavorite']);

//mpesa
Route::post('/getMpesaCallBack', [PaymentCallBack::class, 'getMpesaCallBack']);
//shops
Route::get('/shops', [ShopController::class, 'index']);
Route::get('/admin-shops', [ShopController::class, 'admin_allshops']);
Route::post('/shops', [ShopController::class, 'store']);
Route::put('/shops-live/{id}', [ShopController::class, 'toggleLive']);
Route::put('/products-published/{id}', [ProductController::class, 'togglePublishedProduct']);
Route::put('/products-featured/{id}', [ProductController::class, 'toggleFeaturedProduct']);
//categories
Route::get('/categories', [CategoryController::class, 'index']);
Route::post('/createCategory', [CategoryController::class, 'createCategory']);
//orders
Route::post('/order-create', [OrderController::class, 'create']);
Route::get('/orders/{customerId}', [OrderController::class, 'getOrdersForCustomer']);
Route::get('/admin-orders', [OrderController::class, 'getAllOrders']);
Route::get('/order-details/{id}', [OrderController::class, 'orderDetails']);
Route::put('/order-dispatch/{orderNumber}', [OrderController::class, 'updateOrderStatus']);
Route::put('/order-completed/{orderNumber}', [OrderController::class, 'completedOrderStatus']);
Route::patch('/update-checkoutID-orders/{order}', [OrderController::class, 'updateCheckoutID']);
//become seller
Route::post('/become-seller', [ShopController::class, 'becomeSeller']);


//dashboards
Route::get('/admin-sales-data', [OrderController::class, 'getAdminSalesData']);
Route::get('/seller-dashboard/{sellerid}', [OrderController::class,'getSellerDashboard']);
//reviews
Route::post('/submit-reviews', [ReviewController::class, 'submitReview']);
Route::get('/product-reviews/{productId}', [ReviewController::class, 'getProductReviews']);

//send alert
Route::post('/send-alert', function () {
    // Create a new Request instance with hardcoded values
    $alertData = new Request([
        'userID' => '43',
        'title' => 'Order Confirmation',
        'message' => 'Your order has been placed successfully.',
     
    ]);

    // Instantiate AlertsController and call the sendAlert method
    $alertsController = new AlertsController();
    $alertsController->sendAlert($alertData);

    // Return a success response
    return response()->json(['message' => 'Alert sent successfully.']);
});
Route::get('/db-test', function () {
    try {
        DB::connection()->getPdo();
        return "Database connection is successful.";
    } catch (\Exception $e) {
        return "Could not connect to the database. Please check your configuration. Error: " . $e->getMessage();
    }
});
Route::middleware(['auth:sanctum'])->group(function () {
    
});
